@@ -1,15 +1,14 @@
-
 from MSApi.MSLowApi import caching, MSLowApi
 from MSApi.Template import Template
 from MSApi.ObjectMS import ObjectMS
 
+from MSApi.mixin.RequestLabelMixin import RequestLabelMixin
 from MSApi.mixin.GenListMixin import GenerateListMixin
-from MSApi.mixin.NameMixin import NameMixin
 
 
 class Assortment(ObjectMS,
                  GenerateListMixin,
-                 NameMixin):
+                 RequestLabelMixin):
     _type_name = 'assortment'
 
     @classmethod
