@@ -6,4 +6,4 @@ class CreateNewMixin:
     def create_new(self, **kwargs):
         response = MSLowApi.auch_post('entity/{}'.format(self._type_name), json=self.get_json(), **kwargs)
         error_handler(response)
-        return type(self)(response.json())
\ No newline at end of file
+        self.set_json(response.json())
