@@ -58,5 +58,5 @@ class Filter(object):
 
     @staticmethod
     def _append_filter(filter_, operator, parameter, data):
-        filter_.filters.append(f"{parameter}{operator}{urllib.parse.quote(data)}")
+        filter_.filters.append(f"{parameter}{operator}{urllib.parse.quote(str(data))}")
         return filter_
